from enum import Enum


class AiMethod(Enum):
    # LLAVA_OLLAMA = "LLAVA with ollama server"
    # LLAVA_LOCAL_LLAMACPP = "LLAVA with local power"
    # LLAVA_LLAMACPP_AFTER_OLLAMA = "LLAVA with ollama and llamacpp"

    LLAVA_INNER_JSON = "LLAVA with inner json"
    LLAVA_NORMALE_JSON = "LLAVA with normale json"
